# Example Patterns

This directory contains example pattern files that can be loaded into LifeGrid.

## How to Use

1. Launch the application
2. Click "Load File" button
3. Navigate to this `examples/` directory
4. Select a pattern file (.json)
5. The pattern will be loaded into the current grid

## Creating Your Own Patterns

Create interesting patterns in the simulator and save them using the "Save" button. You can share these JSON files with others!
